==> mdm-api-2023.12.12-01-20231212.064546-1-sources.jar: com/elitesland/cbpl/mdm/rpc/StoreRpcService.java <==
package com.elitesland.cbpl.mdm.rpc;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitesland.cbpl.mdm.rpc.param.resp.FranchiseeStoreRpcDTO;
import com.elitescloud.cloudt.common.base.PagingVO;
import com.elitesland.cbpl.mdm.rpc.param.resp.FranchiseeStoreRpcDTO;
import com.elitescloud.cloudt.common.base.PagingVO;
import com.elitesland.cbpl.mdm.rpc.param.resp.InvoiceRpcDTO;
import com.elitesland.cbpl.mdm.rpc.param.resp.StoreRpcDTO;
import com.elitesland.cbpl.mdm.rpc.param.save.SynStoreIsWhiteParam;
import com.elitesland.cbpl.unicom.annotation.Unicom;
import com.elitesland.cbpl.unicom.domain.InvokeDomain;
import com.elitesland.support.provider.Application;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

@Unicom(domain = InvokeDomain.SUPPORT, path = Application.PATH + StoreRpcService.URI)
public interface StoreRpcService {

    String URI = "/rpc/yst/support/org/store";

    @PostMapping("/findByCode")
    List<StoreRpcDTO> findByCode(@RequestBody List<String> storeCodes);
    @PostMapping("/findById")
    List<StoreRpcDTO> findById(@RequestBody List<Long> findById);
    @PostMapping("/findByCodeOrName")
    List<StoreRpcDTO> findByCodeOrName(@RequestBody String storeCodeOrName);

    @PostMapping("/invoice")
    List<InvoiceRpcDTO> invoiceByStoreCode(@RequestBody List<String> storeCodes);

    @PostMapping("/list")
    List<InvoiceRpcDTO> invoiceList(@RequestBody List<String> invTitleList);
    @PostMapping("/findByCodeOne")
    public StoreRpcDTO findByCodeOne(@RequestParam(value = "storeCodes") String storeCodes);

    @PostMapping("/synStoreIsWhite")
    public ApiResult<Object> synStoreIsWhite(@RequestBody List<SynStoreIsWhiteParam> storeCodeList);

    @PostMapping("/franchiseeCodeQueryStore")
    public List<String> franchiseeCodeQueryStore(@RequestBody String franchiseeCode);
    @PostMapping("/findByFranchiseeCode")
    public List<StoreRpcDTO> findByFranchiseeCode(@RequestBody StoreRpcDTO storeRpcDTO);


    @PostMapping("/queryStoreListByFranchiseeCode")
    public List<StoreRpcDTO> queryStoreListByFranchiseeCode(@RequestParam("franchiseeCode") String franchiseeCode);
    @PostMapping("/queryStoreListByCreateTime")
    public List<StoreRpcDTO> queryStoreListByCreateTime(@RequestParam("startDate") LocalDateTime startDate, @RequestParam("endDate") LocalDateTime endDate);
    @PostMapping("/updateWhCodeByCityCode")
    public ApiResult<Object> updateWhCodeByStoreCode(@RequestBody List<FranchiseeStoreRpcDTO> franchiseeStoreRpcDTOList);

    /**
     * 根据加盟商code查询门店下的开票主体
     * @param franchiseeCode
     * @return
     */
    @PostMapping("/franchiseeCodeQueryInvoice")
    public List<InvoiceRpcDTO> franchiseeCodeQueryInvoice(@RequestParam("storeId") List<Long> storeId,@RequestParam("franchiseeCode") String franchiseeCode);

    /**
     * 根据税号查询支付方式
     * @param accCode
     * @return
     */
    @PostMapping("/storeInfoByAccCode")
    public String[] storeInfoByAccCode(@RequestParam("accCode") String accCode);


    @PostMapping("/findRecentlyStoreCode")
    List<StoreRpcDTO> findRecentlyStoreCode();
}

==> mdm-api-2024-03-04-001-20240304.030541-1-sources.jar: com/elitesland/cbpl/mdm/rpc/StoreRpcService.java <==
package com.elitesland.cbpl.mdm.rpc;

import com.elitescloud.cloudt.common.base.ApiResult;
import com.elitesland.cbpl.mdm.rpc.param.resp.FranchiseeStoreRpcDTO;
import com.elitesland.cbpl.mdm.rpc.param.resp.InvoiceRpcDTO;
import com.elitesland.cbpl.mdm.rpc.param.resp.StoreRpcDTO;
import com.elitesland.cbpl.mdm.rpc.param.save.SynStoreIsWhiteParam;
import com.elitesland.cbpl.unicom.annotation.Unicom;
import com.elitesland.cbpl.unicom.domain.InvokeDomain;
import com.elitesland.support.provider.Application;
import org.springframework.web.bind.annotation.PostMapping;
import org.springframework.web.bind.annotation.RequestBody;
import org.springframework.web.bind.annotation.RequestParam;

import java.time.LocalDateTime;
import java.util.List;
import java.util.Map;

@Unicom(domain = InvokeDomain.SUPPORT, path = Application.PATH + StoreRpcService.URI)
public interface StoreRpcService {

    String URI = "/rpc/yst/support/org/store";

    @PostMapping("/findByCode")
    List<StoreRpcDTO> findByCode(@RequestBody List<String> storeCodes);
    @PostMapping("/findById")
    List<StoreRpcDTO> findById(@RequestBody List<Long> findById);
    @PostMapping("/findByCodeOrName")
    List<StoreRpcDTO> findByCodeOrName(@RequestBody String storeCodeOrName);
    @PostMapping("/findAll")
    List<StoreRpcDTO> findAll(@RequestBody List<String> storeCodeList);

    @PostMapping("/invoice")
    List<InvoiceRpcDTO> invoiceByStoreCode(@RequestBody List<String> storeCodes);

    @PostMapping("/list")
    List<InvoiceRpcDTO> invoiceList(@RequestBody List<String> invTitleList);

    /**
     * 通过税码查询开票抬头信息
     *
     * @param taxNoList
     * @return
     */
    @PostMapping("/invoiceListByTaxNoList")
    List<InvoiceRpcDTO> invoiceListByTaxNoList(@RequestBody List<String> taxNoList);
    @PostMapping("/findByCodeOne")
    public StoreRpcDTO findByCodeOne(@RequestParam(value = "storeCodes") String storeCodes);

    @PostMapping("/synStoreIsWhite")
    public ApiResult<Object> synStoreIsWhite(@RequestBody List<SynStoreIsWhiteParam> storeCodeList);

    @PostMapping("/franchiseeCodeQueryStore")
    public List<String> franchiseeCodeQueryStore(@RequestBody String franchiseeCode);


    @PostMapping("/queryStoreListByFranchiseeCode")
    public List<StoreRpcDTO> queryStoreListByFranchiseeCode(@RequestParam("franchiseeCode") String franchiseeCode);
    @PostMapping("/queryStoreListByCreateTime")
    public List<StoreRpcDTO> queryStoreListByCreateTime(@RequestParam("startDate") LocalDateTime startDate, @RequestParam("endDate") LocalDateTime endDate);
    @PostMapping("/findByFranchiseeCode")
    public List<StoreRpcDTO> findByFranchiseeCode(@RequestBody StoreRpcDTO storeRpcDTO);
    @PostMapping("/updateWhCodeByCityCode")
    public ApiResult<Object> updateWhCodeByStoreCode(@RequestBody List<FranchiseeStoreRpcDTO> franchiseeStoreRpcDTOList);

    /**
     * 根据加盟商code查询门店下的开票主体
     * @param franchiseeCode
     * @return
     */
    @PostMapping("/franchiseeCodeQueryInvoice")
    public List<InvoiceRpcDTO> franchiseeCodeQueryInvoice(@RequestParam("storeId") List<Long> storeId,@RequestParam("franchiseeCode") String franchiseeCode);

    /**
     * 根据税号查询支付方式
     * @param accCode
     * @return
     */
    @PostMapping("/storeInfoByAccCode")
    public String[] storeInfoByAccCode(@RequestParam("accCode") String accCode);


    @PostMapping("/findRecentlyStoreCode")
    List<StoreRpcDTO> findRecentlyStoreCode();


    /**
     * 通过税号查询关联门店
     *
     * @param taxNoList
     * @return
     */
    @PostMapping("/queryStoreCodeByTaxNoInInvoice")
    Map<String, List<String>> queryStoreCodeByTaxNoInInvoice(@RequestParam("taxNoList") List<String> taxNoList);

}
